@@ -129,7 +129,7 @@ def _process_one(prefix, schema, mandatory, entities, convert):
             C = _get_contraints(schema)
             D = _add_constraints(D, C)
             for x in _process_one(prefix, schema['items'], False, entities, convert):
-                yield (x[0], 'Array of ' + x[1], D + x[2], mandatory)
+                yield [x[0], 'Array of ' + x[1], D + x[2], mandatory]
     elif type == 'object':
         required = schema.get('required', [])
         for prop_name, prop in schema.get('properties', {}).items():
@@ -264,8 +264,11 @@ def _entities(spec, ref):
     m.update(spec.get('info', {}).get('title', '').encode('utf-8'))
     m.update(spec.get('info', {}).get('version', '0.0').encode('utf-8'))
     key = m.hexdigest()
+    # for unit tests
     if key == '30565a8911a6bb487e3745c0ea3c8224':
         key = ''
+    if '#' in ref:
+        ref = ref.split('#')[1]
     return key + ref
 
 
